function MDVA = ff_correct(DFF)
% c 2005 Nicola Zamboni - Fiatflux
lab_atom_corr=1;
%global FR;
FR = DFF.A; % the file of the aa properties YS
%[A_tot,frags] = size(DFF.spectra);

ran = max([length(DFF.spectra(1,2).corrsum) length(DFF.spectra(1,3).corrsum) length(DFF.spectra(12,2).corrsum) length(DFF.spectra(2,2).corrsum) length(DFF.spectra(3,3).corrsum)]) ;

%natural abundances of stable isotopes
C = [0.98900 0.01100];
O = [0.99759 0.00037 0.00204];
N = [0.99630 0.00370];
H = [0.99985 0.00015];
Si = [0.92180 0.04700 0.03120];
S = [0.95018 0.00750 0.04215 0.00017];
isos = zeros(length(FR),5,6);
REMOVELIST = [];
%unmeasured aminoacids
for i = 1:length(FR)
    len = size(FR(i).frag.mz,2);
    for j = 1:len,
        if isempty(DFF.spectra(i,j).corrsum)  % no amino acid peak detected
            REMOVELIST = [REMOVELIST ; [i j]];
        else
            for k = 1:6
                if ismember(k,DFF.p.label)
                    isos(i,j,k)= FR(i).frag.formula(j).d(k);
                else
                    isos(i,j,k)= FR(i).frag.formula(j).d(k) + FR(i).frag.formula(j).b(k);
                end
            end
            measnorm{i,j} = DFF.spectra(i,j).corrsum(1:(min([ran FR(i).frag.formula(j).b(1)+5])))./(DFF.spectra(i,j).corrsum(1)+eps); %scales intensities to m0
        end
    end
end

% generate Corr matrices

%C
ind = unique(isos(:,:,1))';
for n = ind
    C_corr{1} = 1;
    for k = 1 : n + 1
        C_corr{n+1}(k) = C(1)^(n-(k-1))*C(2)^(k-1)*nchoosek(n,(k-1));
    end
end

%H
ind = unique(isos(:,:,2))';
for n = ind
    H_corr{1} = 1;
    for k = 1 : n + 1
        H_corr{n+1}(k) = H(1)^(n-(k-1))*H(2)^(k-1)*nchoosek(n,(k-1));
    end
end

%N
ind = unique(isos(:,:,3))';
for n = ind
    N_corr{1} = 1;
    for k = 1 : n + 1
        N_corr{n+1}(k) = N(1)^(n-(k-1))*N(2)^(k-1)*nchoosek(n,(k-1));
    end
end

%O
nmax = max(max(isos(:,:,4)));
O_corr{1}=1;
for n = 1 : nmax
    O_corr{n+1} = fCv(O_corr{n},O);
end

%Si
nmax = max(max(isos(:,:,5)));
Si_corr{1}=1;
for n = 1 : nmax
    Si_corr{n+1} = fCv(Si_corr{n},Si);
end

%S
nmax = max(max(isos(:,:,6)));
S_corr{1}=1;
for n = 1 : nmax
    S_corr{n+1} = fCv(S_corr{n},S);
end

for i = 1:length(FR)
    for j = 1:size(FR(i).frag.mz,2)
        if size(REMOVELIST,1)
            ij = intersect(find(REMOVELIST(:,1)==i), find(REMOVELIST(:,2)==j));
        else
            ij = [];
        end
        if isempty(ij) & length(measnorm{i,j})>0
            CONHSiS_corr = fCv(fCv(fCv(fCv(fCv(C_corr{isos(i,j,1)+1},O_corr{isos(i,j,4)+1}),N_corr{isos(i,j,3)+1}),H_corr{isos(i,j,2)+1}),Si_corr{isos(i,j,5)+1}),S_corr{isos(i,j,6)+1});%combine all vectors
            Corr = CONHSiS_corr(1:length(measnorm{i,j}))/CONHSiS_corr(1);
            Correct = fUcv(measnorm{i,j},Corr);
            lab_atoms = sum(FR(i).frag.formula(j).b(DFF.p.label));
            MDVA(i,j).raw = measnorm{i,j}./sum(measnorm{i,j});
            MDVA(i,j).corr_nat_iso = Correct(1:(lab_atoms+lab_atom_corr))/sum(Correct(1:(lab_atoms+lab_atom_corr))+eps);
        else
            MDVA(i,j).corr_nat_iso = zeros(1,sum(FR(i).frag.formula(j).b(DFF.p.label))+1);
            MDVA(i,j).corr_nat_iso(1) = 1;
        end
    end
end

%---------------------------------------------------------------------------------------------------------
    function [uncomb] = fUcv(v1, v2);

        for i = 1:length(v1)
            sum = 0;
            for j = 1:(i-1)
                sum = sum+clab(j)*v2(i-j+1);
            end
            clab(i)= (v1(i)-sum)/v2(1);
        end
        uncomb=clab;

        %--------------------------------------------------------------------------------------------------------
        function [combvec] = fCv(v1,v2);
            mat =[];
            for i = 1:length(v1)
                for j = 1:length(v2)
                    mat(i,j+i-1) =v1(i)*v2(j);
                end
            end
            combvec = sum(mat,1);

            %%----------------------------------------------------------------------------------------------------
            function fl = fFL(v)
                fl=0;
                for i = 1:length(v)
                    fl = fl+(i-1)*v(i);
                end
                fl = fl/(length(v)-1);